const LineNumbersRegex = /{([\d,\s-]+)}/;
export const LineNumberAttrRegex = /^([\d,\s-]+)/;
const highlightCodeLines = (md, { enable } = {}) => {
    const fence = md.renderer.rules.fence;
    md.renderer.rules.fence = (tokens, idx, options, env, self) => {
        const token = tokens[idx];
        if ((enable != null && !enable(md)) ||
            token.attrs == null ||
            token.attrs.some(([attr]) => LineNumberAttrRegex.test(attr)) === false) {
            return fence(tokens, idx, options, env, self);
        }
        let highlightedLines = [];
        try {
            highlightedLines = Array.from(new Set(token.attrs
                .map(([attr]) => attr.split(',').map(x => x.trim()))
                .flat()
                .filter(attr => attr != null && attr.length > 0 && LineNumberAttrRegex.test(attr))
                .map(v => {
                let [start, end] = v.split(/\s*?-\s*?/).map(v => parseInt(v.trim(), 10));
                start = start > 0 ? start : 1;
                end = end > start ? end : start;
                const paddedArr = new Array((start > end ? start - end : end - start) + 1).fill(0);
                paddedArr.forEach((_, idx) => {
                    paddedArr[idx] = start + idx;
                });
                return paddedArr;
            })
                .flat()));
        }
        catch (ex) {
            console.warn(ex);
        }
        const langName = token.info.replace(LineNumbersRegex, '').trim();
        let code = md.utils.escapeHtml(token.content);
        code = options.highlight ? options.highlight(code, langName, '') : code;
        const tmpToken = Object.assign(token, {
            attrs: [
                ['class', langName ? `language-${langName}` : ''],
                highlightedLines && highlightedLines.length > 0
                    ? ['data-lines-highlight', `[${highlightedLines.join(',')}]`]
                    : [],
            ],
        });
        const attrs = self.renderAttrs(tmpToken);
        return `<pre${attrs}><code${attrs}>${code.trim()}</code></pre>`;
    };
};
export { highlightCodeLines as HighlightCodeLinesPlugin };
//# sourceMappingURL=highlight-code-lines.plugin.js.map